# Copyright: 2007-2009 Paul Obermeier (obermeier@poSoft.de)
# Distributed under BSD license.

set auto_path [linsert $auto_path 0 [pwd]]

package require tcomexcel

# Test settings: Name of Excel file being generated.
#                Number of test rows and columns being generated.
# Note:
# The actual number of rows will be numRows+1, 
# because the first row contains header information.
# The actual number of columns will be numCols+1, 
# because the first column contains time information.
set xlsFile [file join [pwd] "testOut" "TestMisc.xls"]
set numRows  100
set numCols  10 

# Test preparation: Delete Excel test file from maybe previous test.
#                   Generate lists with test data
file delete -force $xlsFile

for { set i 1 } { $i <= $numCols } { incr i } {
    lappend entList "$i"
}

# Test start: Open Excel, show the application window and create a workbook.
set appId [::Excel::Open]
set workbookId [::Excel::AddWorkbook $appId]

# Perform test 1:
# Interpret the data as flight paths and display each data column as a line.
# The time column is used for the X axis.

# Create a worksheet and set its name.
# We use the first already existing worksheet for our first test.
# Mainly because otherwise our charts are not placed on the intended
# worksheet, but on the first default one. (Bug in Excel 2000, in Excel 2003
# this works correctly.
# set worksheetId [::Excel::AddWorksheet $workbookId]
set worksheetId [::Excel::GetWorksheetIdByIndex $workbookId 1]
::Excel::SetWorksheetName $worksheetId "TestMisc"
set cellsId [::Excel::GetCellsId $worksheetId]

set t1 [clock clicks -milliseconds]
for { set i 1 } { $i <= $numRows } { incr i } {
    ::Excel::SetRowValues  $cellsId $i 1 $entList
    #::Excel::SetRowValuesFast $cellsId $i 1 $entList
}
set t2 [clock clicks -milliseconds]
puts "[expr $t2 - $t1] ms to set row values."

set rangeId [::Excel::SelectCellByIndex $cellsId 2 1 true]
::Excel::SetRangeFillColor $rangeId 255 0 0
::Excel::SetRangeTextColor $rangeId 0 255 0

set rangeId [::Excel::SelectCellByIndex $cellsId 3 1 true]
::Excel::SetRangeFillColor $rangeId 0 255 0
::Excel::SetRangeTextColor $rangeId 0 0 255

set rangeId [::Excel::SelectCellByIndex $cellsId 4 1 true]
::Excel::SetRangeFillColor $rangeId 0 0 255
::Excel::SetRangeTextColor $rangeId 255 0 0

set rangeId [::Excel::SelectRangeByIndex $cellsId 5 1 6 3 true]
::Excel::SetRangeFillColor $rangeId 255 255 0
::Excel::SetRangeTextColor $rangeId 0 255 255

$rangeId NumberFormat [::Excel::GetLangNumberFormat "0" "0000000"]

set cell [::Excel::SelectCellByIndex $cellsId 1 1 true]
set funcName [::Excel::GetLangFuncName "TODAY" "()"]
$cell Formula "=$funcName"
puts "[$cell Formula]"
puts "[$cell FormulaLocal]"

::Excel::SetColumnsWidth $cellsId 1 $numCols 0
::Excel::SetColumnWidth $cellsId 1 20
::Excel::SetColumnWidth $cellsId 5 10

# Generate a text file for testing the hyperlink capabilities.
set fileName [file join [pwd] "testOut" "TestMisc.txt"]
set fp [open $fileName "w"]
puts $fp "This is the linked text file."
close $fp

::Excel::SetHyperlink $worksheetId 1 [expr $numCols + 1] \
                      [format "file://%s" $fileName] "Hyperlink"

::Excel::SetCellValue $cellsId 2 [expr $numCols + 1] "Hallo"
::Excel::SetCellValue $cellsId 3 [expr $numCols + 1] "Holla"

set cell [::Excel::FindCell $cellsId "Hallo"]
set rowNum [lindex $cell 0]
set colNum [lindex $cell 1]
puts "Found string \"Hallo\" at cell [::Excel::ColumnIntToChar $colNum]$rowNum"

set picId [::Excel::InsertImage $worksheetId [file join [pwd] "wish.gif"] 5 9]
::Excel::ScaleImage $picId 2 2.5

set newWorksheetId [::Excel::AddWorksheet $workbookId "WorksheetCopy"]
::Excel::CopyWorksheet $worksheetId $newWorksheetId

puts "Saving as Excel file: $xlsFile"
::Excel::SaveAs $workbookId $xlsFile
